{% load i18n static %}
<link rel="stylesheet" type="text/css" href="{% static 'maploom/assets/MapLoom-1.1.css' %}"/>
<script type="text/javascript" src="{% static 'maploom/assets/MapLoom-1.1.js' %}"></script>
